Class: Aws::PI::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PI::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pi/client.rb,
sig/client.rbs
Overview
An API client for PI. To construct a client, you need to configure a :region and :credentials.
client = Aws::PI::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreatePerformanceAnalysisReportResponseSuccess, _DeletePerformanceAnalysisReportResponseSuccess, _DescribeDimensionKeysResponseSuccess, _GetDimensionKeyDetailsResponseSuccess, _GetPerformanceAnalysisReportResponseSuccess, _GetResourceMetadataResponseSuccess, _GetResourceMetricsResponseSuccess, _ListAvailableResourceDimensionsResponseSuccess, _ListAvailableResourceMetricsResponseSuccess, _ListPerformanceAnalysisReportRecommendationsResponseSuccess, _ListPerformanceAnalysisReportsResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_performance_analysis_report(params = {}) ⇒ Types::CreatePerformanceAnalysisReportResponse
Creates a new performance analysis report for a specific time period for the DB instance.
-
#delete_performance_analysis_report(params = {}) ⇒ Struct
Deletes a performance analysis report.
-
#describe_dimension_keys(params = {}) ⇒ Types::DescribeDimensionKeysResponse
For a specific time period, retrieve the top
Ndimension keys for a metric. -
#get_dimension_key_details(params = {}) ⇒ Types::GetDimensionKeyDetailsResponse
Get the attributes of the specified dimension group for a DB instance or data source.
-
#get_performance_analysis_report(params = {}) ⇒ Types::GetPerformanceAnalysisReportResponse
Retrieves the report including the report ID, status, time details, and the insights with recommendations.
-
#get_resource_metadata(params = {}) ⇒ Types::GetResourceMetadataResponse
Retrieve the metadata for different features.
-
#get_resource_metrics(params = {}) ⇒ Types::GetResourceMetricsResponse
Retrieve Performance Insights metrics for a set of data sources over a time period.
-
#list_available_resource_dimensions(params = {}) ⇒ Types::ListAvailableResourceDimensionsResponse
Retrieve the dimensions that can be queried for each specified metric type on a specified DB instance.
-
#list_available_resource_metrics(params = {}) ⇒ Types::ListAvailableResourceMetricsResponse
Retrieve metrics of the specified types that can be queried for a specified DB instance.
-
#list_performance_analysis_report_recommendations(params = {}) ⇒ Types::ListPerformanceAnalysisReportRecommendationsResponse
Retrieves recommendations for a performance analysis report.
-
#list_performance_analysis_reports(params = {}) ⇒ Types::ListPerformanceAnalysisReportsResponse
Lists all the analysis reports created for the DB instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all the metadata tags associated with Amazon RDS Performance Insights resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to the Amazon RDS Performance Insights resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the metadata tags from the Amazon RDS Performance Insights resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-pi/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1590 1591 1592 |
# File 'lib/aws-sdk-pi/client.rb', line 1590 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1593 1594 1595 |
# File 'lib/aws-sdk-pi/client.rb', line 1593 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 |
# File 'lib/aws-sdk-pi/client.rb', line 1563 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PI') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pi' context[:gem_version] = '1.98.0' Seahorse::Client::Request.new(handlers, context) end |
#create_performance_analysis_report(params = {}) ⇒ Types::CreatePerformanceAnalysisReportResponse
Creates a new performance analysis report for a specific time period for the DB instance.
87 |
# File 'sig/client.rbs', line 87
def create_performance_analysis_report: (
|
#delete_performance_analysis_report(params = {}) ⇒ Struct
Deletes a performance analysis report.
105 |
# File 'sig/client.rbs', line 105
def delete_performance_analysis_report: (
|
#describe_dimension_keys(params = {}) ⇒ Types::DescribeDimensionKeysResponse
For a specific time period, retrieve the top N dimension keys for a
metric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
121 |
# File 'sig/client.rbs', line 121
def describe_dimension_keys: (
|
#get_dimension_key_details(params = {}) ⇒ Types::GetDimensionKeyDetailsResponse
Get the attributes of the specified dimension group for a DB instance
or data source. For example, if you specify a SQL ID,
GetDimensionKeyDetails retrieves the full text of the dimension
db.sql.statement associated with this ID. This operation is useful
because GetResourceMetrics and DescribeDimensionKeys don't
support retrieval of large SQL statement text, lock snapshots, and
execution plans.
150 |
# File 'sig/client.rbs', line 150
def get_dimension_key_details: (
|
#get_performance_analysis_report(params = {}) ⇒ Types::GetPerformanceAnalysisReportResponse
Retrieves the report including the report ID, status, time details,
and the insights with recommendations. The report status can be
RUNNING, SUCCEEDED, or FAILED. The insights include the
description and recommendation fields.
164 |
# File 'sig/client.rbs', line 164
def get_performance_analysis_report: (
|
#get_resource_metadata(params = {}) ⇒ Types::GetResourceMetadataResponse
Retrieve the metadata for different features. For example, the metadata might indicate that a feature is turned on or off on a specific DB instance.
179 |
# File 'sig/client.rbs', line 179
def get_resource_metadata: (
|
#get_resource_metrics(params = {}) ⇒ Types::GetResourceMetricsResponse
Retrieve Performance Insights metrics for a set of data sources over a time period. You can provide specific dimension groups and dimensions, and provide filtering criteria for each group. You must specify an aggregate function for each metric.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
194 |
# File 'sig/client.rbs', line 194
def get_resource_metrics: (
|
#list_available_resource_dimensions(params = {}) ⇒ Types::ListAvailableResourceDimensionsResponse
Retrieve the dimensions that can be queried for each specified metric type on a specified DB instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
223 |
# File 'sig/client.rbs', line 223
def list_available_resource_dimensions: (
|
#list_available_resource_metrics(params = {}) ⇒ Types::ListAvailableResourceMetricsResponse
Retrieve metrics of the specified types that can be queried for a specified DB instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
239 |
# File 'sig/client.rbs', line 239
def list_available_resource_metrics: (
|
#list_performance_analysis_report_recommendations(params = {}) ⇒ Types::ListPerformanceAnalysisReportRecommendationsResponse
Retrieves recommendations for a performance analysis report.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
254 |
# File 'sig/client.rbs', line 254
def list_performance_analysis_report_recommendations: (
|
#list_performance_analysis_reports(params = {}) ⇒ Types::ListPerformanceAnalysisReportsResponse
Lists all the analysis reports created for the DB instance. The reports are sorted based on the start time of each report.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
270 |
# File 'sig/client.rbs', line 270
def list_performance_analysis_reports: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all the metadata tags associated with Amazon RDS Performance Insights resource.
284 |
# File 'sig/client.rbs', line 284
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to the Amazon RDS Performance Insights resource.
294 |
# File 'sig/client.rbs', line 294
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes the metadata tags from the Amazon RDS Performance Insights resource.
310 |
# File 'sig/client.rbs', line 310
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1583 1584 1585 |
# File 'lib/aws-sdk-pi/client.rb', line 1583 def waiter_names [] end |