Class: Aws::PI::Types::DescribeDimensionKeysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PI::Types::DescribeDimensionKeysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pi/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_metrics ⇒ Array<String>
Additional metrics for the top
Ndimension keys. -
#end_time ⇒ Time
The date and time specifying the end of the requested time series data.
-
#filter ⇒ Hash<String,String>
One or more filters to apply in the request.
-
#group_by ⇒ Types::DimensionGroup
A specification for how to aggregate the data points from a query result.
-
#identifier ⇒ String
An immutable, Amazon Web Services Region-unique identifier for a data source.
-
#max_results ⇒ Integer
The maximum number of items to return in the response.
-
#metric ⇒ String
The name of a Performance Insights metric to be measured.
-
#next_token ⇒ String
An optional pagination token provided by a previous request.
-
#partition_by ⇒ Types::DimensionGroup
For each dimension specified in
GroupBy, specify a secondary dimension to further subdivide the partition keys in the response. -
#period_in_seconds ⇒ Integer
The granularity, in seconds, of the data points returned from Performance Insights.
-
#service_type ⇒ String
The Amazon Web Services service for which Performance Insights will return metrics.
-
#start_time ⇒ Time
The date and time specifying the beginning of the requested time series data.
Instance Attribute Details
#additional_metrics ⇒ Array<String>
Additional metrics for the top N dimension keys. If the specified dimension group in the GroupBy parameter is db.sql_tokenized, you can specify per-SQL metrics to get the values for the top N SQL digests. The response syntax is as follows: ‘“AdditionalMetrics” : { “string” : “string” }`.
The only supported statistic function is .avg.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The date and time specifying the end of the requested time series data. The value specified is exclusive, which means that data points less than (but not equal to) EndTime are returned.
The value for EndTime must be later than the value for StartTime.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Hash<String,String>
One or more filters to apply in the request. Restrictions:
-
Any number of filters by the same dimension, as specified in the
GroupByorPartitionparameters. -
A single filter for any other dimension in this dimension group.
<note markdown=“1”> The db.sql.db_id filter isn’t available for RDS for SQL Server DB instances.
</note>
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ Types::DimensionGroup
A specification for how to aggregate the data points from a query result. You must specify a valid dimension group. Performance Insights returns all dimensions within this group, unless you provide the names of specific dimensions within this group. You can also request that Performance Insights return a limited number of values for a dimension.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
An immutable, Amazon Web Services Region-unique identifier for a data source. Performance Insights gathers metrics from this data source.
To use an Amazon RDS instance as a data source, you specify its DbiResourceId value. For example, specify db-FAIHNTYBKTGAUSUZQYPDS2GW4A.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in the response. If more items exist than the specified MaxRecords value, a pagination token is included in the response so that the remaining results can be retrieved.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
The name of a Performance Insights metric to be measured.
Valid values for Metric are:
-
db.load.avg- A scaled representation of the number of active sessions for the database engine. -
db.sampledload.avg- The raw number of active sessions for the database engine.
If the number of active sessions is less than an internal Performance Insights threshold, db.load.avg and db.sampledload.avg are the same value. If the number of active sessions is greater than the internal threshold, Performance Insights samples the active sessions, with db.load.avg showing the scaled values, db.sampledload.avg showing the raw values, and db.sampledload.avg less than db.load.avg. For most use cases, you can query db.load.avg only.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the token, up to the value specified by MaxRecords.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#partition_by ⇒ Types::DimensionGroup
For each dimension specified in GroupBy, specify a secondary dimension to further subdivide the partition keys in the response.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#period_in_seconds ⇒ Integer
The granularity, in seconds, of the data points returned from Performance Insights. A period can be as short as one second, or as long as one day (86400 seconds). Valid values are:
-
1(one second) -
60(one minute) -
300(five minutes) -
3600(one hour) -
86400(twenty-four hours)
If you don’t specify PeriodInSeconds, then Performance Insights chooses a value for you, with a goal of returning roughly 100-200 data points in the response.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#service_type ⇒ String
The Amazon Web Services service for which Performance Insights will return metrics. Valid values are as follows:
-
RDS -
DOCDB
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time specifying the beginning of the requested time series data. You must specify a StartTime within the past 7 days. The value specified is inclusive, which means that data points equal to or greater than StartTime are returned.
The value for StartTime must be earlier than the value for EndTime.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/aws-sdk-pi/types.rb', line 365 class DescribeDimensionKeysRequest < Struct.new( :service_type, :identifier, :start_time, :end_time, :metric, :period_in_seconds, :group_by, :additional_metrics, :partition_by, :filter, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |