Class: Aws::PI::Types::GetPerformanceAnalysisReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PI::Types::GetPerformanceAnalysisReportRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pi/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accept_language ⇒ String
The text language in the report.
-
#analysis_report_id ⇒ String
A unique identifier of the created analysis report.
-
#identifier ⇒ String
An immutable identifier for a data source that is unique for an Amazon Web Services Region.
-
#service_type ⇒ String
The Amazon Web Services service for which Performance Insights will return metrics.
-
#text_format ⇒ String
Indicates the text format in the report.
Instance Attribute Details
#accept_language ⇒ String
The text language in the report. The default language is EN_US (English).
923 924 925 926 927 928 929 930 931 |
# File 'lib/aws-sdk-pi/types.rb', line 923 class GetPerformanceAnalysisReportRequest < Struct.new( :service_type, :identifier, :analysis_report_id, :text_format, :accept_language) SENSITIVE = [] include Aws::Structure end |
#analysis_report_id ⇒ String
A unique identifier of the created analysis report. For example, report-12345678901234567
923 924 925 926 927 928 929 930 931 |
# File 'lib/aws-sdk-pi/types.rb', line 923 class GetPerformanceAnalysisReportRequest < Struct.new( :service_type, :identifier, :analysis_report_id, :text_format, :accept_language) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
An immutable identifier for a data source that is unique for an Amazon Web Services Region. Performance Insights gathers metrics from this data source. In the console, the identifier is shown as ResourceID. When you call DescribeDBInstances, the identifier is returned as DbiResourceId.
To use a DB instance as a data source, specify its DbiResourceId value. For example, specify db-ABCDEFGHIJKLMNOPQRSTU1VW2X.
923 924 925 926 927 928 929 930 931 |
# File 'lib/aws-sdk-pi/types.rb', line 923 class GetPerformanceAnalysisReportRequest < Struct.new( :service_type, :identifier, :analysis_report_id, :text_format, :accept_language) SENSITIVE = [] include Aws::Structure end |
#service_type ⇒ String
The Amazon Web Services service for which Performance Insights will return metrics. Valid value is RDS.
923 924 925 926 927 928 929 930 931 |
# File 'lib/aws-sdk-pi/types.rb', line 923 class GetPerformanceAnalysisReportRequest < Struct.new( :service_type, :identifier, :analysis_report_id, :text_format, :accept_language) SENSITIVE = [] include Aws::Structure end |
#text_format ⇒ String
Indicates the text format in the report. The options are PLAIN_TEXT or MARKDOWN. The default value is ‘plain text`.
923 924 925 926 927 928 929 930 931 |
# File 'lib/aws-sdk-pi/types.rb', line 923 class GetPerformanceAnalysisReportRequest < Struct.new( :service_type, :identifier, :analysis_report_id, :text_format, :accept_language) SENSITIVE = [] include Aws::Structure end |