Class: Aws::PI::Types::Recommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::PI::Types::Recommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pi/types.rb
Overview
The list of recommendations for the insight.
Constant Summary collapse
- SENSITIVE =
[:recommendation_description, :recommendation_details]
Instance Attribute Summary collapse
-
#recommendation_description ⇒ String
The recommendation details to help resolve the performance issue.
-
#recommendation_details ⇒ String
Detailed information about the recommendation, including steps to resolve the performance issue.
-
#recommendation_id ⇒ String
The unique identifier for the recommendation.
Instance Attribute Details
#recommendation_description ⇒ String
The recommendation details to help resolve the performance issue. For example, ‘Investigate the following SQLs that contributed to 100% of the total DBLoad during that time period: sql-id`
1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-pi/types.rb', line 1740 class Recommendation < Struct.new( :recommendation_id, :recommendation_description, :recommendation_details) SENSITIVE = [:recommendation_description, :recommendation_details] include Aws::Structure end |
#recommendation_details ⇒ String
Detailed information about the recommendation, including steps to resolve the performance issue.
1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-pi/types.rb', line 1740 class Recommendation < Struct.new( :recommendation_id, :recommendation_description, :recommendation_details) SENSITIVE = [:recommendation_description, :recommendation_details] include Aws::Structure end |
#recommendation_id ⇒ String
The unique identifier for the recommendation.
1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/aws-sdk-pi/types.rb', line 1740 class Recommendation < Struct.new( :recommendation_id, :recommendation_description, :recommendation_details) SENSITIVE = [:recommendation_description, :recommendation_details] include Aws::Structure end |