Class: Aws::PI::Types::ResponseResourceMetricKey
- Inherits:
-
Struct
- Object
- Struct
- Aws::PI::Types::ResponseResourceMetricKey
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pi/types.rb
Overview
An object describing a Performance Insights metric and one or more dimensions for that metric.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Hash<String,String>
The valid dimensions for the metric.
-
#metric ⇒ String
The name of a Performance Insights metric to be measured.
Instance Attribute Details
#dimensions ⇒ Hash<String,String>
The valid dimensions for the metric.
1754 1755 1756 1757 1758 1759 |
# File 'lib/aws-sdk-pi/types.rb', line 1754 class ResponseResourceMetricKey < Struct.new( :metric, :dimensions) SENSITIVE = [] include Aws::Structure end |
#metric ⇒ String
The name of a Performance Insights metric to be measured.
Valid values for Metric are:
-
db.load.avg- A scaled representation of the number of active sessions for the database engine. -
db.sampledload.avg- The raw number of active sessions for the database engine. -
The counter metrics listed in [Performance Insights operating system counters] in the *Amazon Aurora User Guide*.
-
The counter metrics listed in [Performance Insights operating system counters] in the *Amazon RDS User Guide*.
If the number of active sessions is less than an internal Performance Insights threshold, db.load.avg and db.sampledload.avg are the same value. If the number of active sessions is greater than the internal threshold, Performance Insights samples the active sessions, with db.load.avg showing the scaled values, db.sampledload.avg showing the raw values, and db.sampledload.avg less than db.load.avg. For most use cases, you can query db.load.avg only.
[1]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_PerfInsights_Counters.html#USER_PerfInsights_Counters.OS [2]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_PerfInsights_Counters.html#USER_PerfInsights_Counters.OS
1754 1755 1756 1757 1758 1759 |
# File 'lib/aws-sdk-pi/types.rb', line 1754 class ResponseResourceMetricKey < Struct.new( :metric, :dimensions) SENSITIVE = [] include Aws::Structure end |