Class: Aws::PI::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PI::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pi/client.rb
Overview
An API client for PI. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PI::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_performance_analysis_report(params = {}) ⇒ Types::CreatePerformanceAnalysisReportResponse
Creates a new performance analysis report for a specific time period for the DB instance.
-
#delete_performance_analysis_report(params = {}) ⇒ Struct
Deletes a performance analysis report.
-
#describe_dimension_keys(params = {}) ⇒ Types::DescribeDimensionKeysResponse
For a specific time period, retrieve the top ‘N` dimension keys for a metric.
-
#get_dimension_key_details(params = {}) ⇒ Types::GetDimensionKeyDetailsResponse
Get the attributes of the specified dimension group for a DB instance or data source.
-
#get_performance_analysis_report(params = {}) ⇒ Types::GetPerformanceAnalysisReportResponse
Retrieves the report including the report ID, status, time details, and the insights with recommendations.
-
#get_resource_metadata(params = {}) ⇒ Types::GetResourceMetadataResponse
Retrieve the metadata for different features.
-
#get_resource_metrics(params = {}) ⇒ Types::GetResourceMetricsResponse
Retrieve Performance Insights metrics for a set of data sources over a time period.
-
#list_available_resource_dimensions(params = {}) ⇒ Types::ListAvailableResourceDimensionsResponse
Retrieve the dimensions that can be queried for each specified metric type on a specified DB instance.
-
#list_available_resource_metrics(params = {}) ⇒ Types::ListAvailableResourceMetricsResponse
Retrieve metrics of the specified types that can be queried for a specified DB instance.
-
#list_performance_analysis_reports(params = {}) ⇒ Types::ListPerformanceAnalysisReportsResponse
Lists all the analysis reports created for the DB instance.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all the metadata tags associated with Amazon RDS Performance Insights resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to the Amazon RDS Performance Insights resource.
-
#untag_resource(params = {}) ⇒ Struct
Deletes the metadata tags from the Amazon RDS Performance Insights resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-pi/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1520 1521 1522 |
# File 'lib/aws-sdk-pi/client.rb', line 1520 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1523 1524 1525 |
# File 'lib/aws-sdk-pi/client.rb', line 1523 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/aws-sdk-pi/client.rb', line 1493 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PI') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pi' context[:gem_version] = '1.95.0' Seahorse::Client::Request.new(handlers, context) end |
#create_performance_analysis_report(params = {}) ⇒ Types::CreatePerformanceAnalysisReportResponse
Creates a new performance analysis report for a specific time period for the DB instance.
536 537 538 539 |
# File 'lib/aws-sdk-pi/client.rb', line 536 def create_performance_analysis_report(params = {}, = {}) req = build_request(:create_performance_analysis_report, params) req.send_request() end |
#delete_performance_analysis_report(params = {}) ⇒ Struct
Deletes a performance analysis report.
574 575 576 577 |
# File 'lib/aws-sdk-pi/client.rb', line 574 def delete_performance_analysis_report(params = {}, = {}) req = build_request(:delete_performance_analysis_report, params) req.send_request() end |
#describe_dimension_keys(params = {}) ⇒ Types::DescribeDimensionKeysResponse
For a specific time period, retrieve the top ‘N` dimension keys for a metric.
<note markdown=“1”> Each response element returns a maximum of 500 bytes. For larger elements, such as SQL statements, only the first 500 bytes are returned.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
761 762 763 764 |
# File 'lib/aws-sdk-pi/client.rb', line 761 def describe_dimension_keys(params = {}, = {}) req = build_request(:describe_dimension_keys, params) req.send_request() end |
#get_dimension_key_details(params = {}) ⇒ Types::GetDimensionKeyDetailsResponse
Get the attributes of the specified dimension group for a DB instance or data source. For example, if you specify a SQL ID, ‘GetDimensionKeyDetails` retrieves the full text of the dimension `db.sql.statement` associated with this ID. This operation is useful because `GetResourceMetrics` and `DescribeDimensionKeys` don’t support retrieval of large SQL statement text, lock snapshots, and execution plans.
860 861 862 863 |
# File 'lib/aws-sdk-pi/client.rb', line 860 def get_dimension_key_details(params = {}, = {}) req = build_request(:get_dimension_key_details, params) req.send_request() end |
#get_performance_analysis_report(params = {}) ⇒ Types::GetPerformanceAnalysisReportResponse
Retrieves the report including the report ID, status, time details, and the insights with recommendations. The report status can be ‘RUNNING`, `SUCCEEDED`, or `FAILED`. The insights include the `description` and `recommendation` fields.
952 953 954 955 |
# File 'lib/aws-sdk-pi/client.rb', line 952 def get_performance_analysis_report(params = {}, = {}) req = build_request(:get_performance_analysis_report, params) req.send_request() end |
#get_resource_metadata(params = {}) ⇒ Types::GetResourceMetadataResponse
Retrieve the metadata for different features. For example, the metadata might indicate that a feature is turned on or off on a specific DB instance.
994 995 996 997 |
# File 'lib/aws-sdk-pi/client.rb', line 994 def (params = {}, = {}) req = build_request(:get_resource_metadata, params) req.send_request() end |
#get_resource_metrics(params = {}) ⇒ Types::GetResourceMetricsResponse
Retrieve Performance Insights metrics for a set of data sources over a time period. You can provide specific dimension groups and dimensions, and provide filtering criteria for each group. You must specify an aggregate function for each metric.
<note markdown=“1”> Each response element returns a maximum of 500 bytes. For larger elements, such as SQL statements, only the first 500 bytes are returned.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1139 1140 1141 1142 |
# File 'lib/aws-sdk-pi/client.rb', line 1139 def get_resource_metrics(params = {}, = {}) req = build_request(:get_resource_metrics, params) req.send_request() end |
#list_available_resource_dimensions(params = {}) ⇒ Types::ListAvailableResourceDimensionsResponse
Retrieve the dimensions that can be queried for each specified metric type on a specified DB instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1215 1216 1217 1218 |
# File 'lib/aws-sdk-pi/client.rb', line 1215 def list_available_resource_dimensions(params = {}, = {}) req = build_request(:list_available_resource_dimensions, params) req.send_request() end |
#list_available_resource_metrics(params = {}) ⇒ Types::ListAvailableResourceMetricsResponse
Retrieve metrics of the specified types that can be queried for a specified DB instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1287 1288 1289 1290 |
# File 'lib/aws-sdk-pi/client.rb', line 1287 def list_available_resource_metrics(params = {}, = {}) req = build_request(:list_available_resource_metrics, params) req.send_request() end |
#list_performance_analysis_reports(params = {}) ⇒ Types::ListPerformanceAnalysisReportsResponse
Lists all the analysis reports created for the DB instance. The reports are sorted based on the start time of each report.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1357 1358 1359 1360 |
# File 'lib/aws-sdk-pi/client.rb', line 1357 def list_performance_analysis_reports(params = {}, = {}) req = build_request(:list_performance_analysis_reports, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves all the metadata tags associated with Amazon RDS Performance Insights resource.
1400 1401 1402 1403 |
# File 'lib/aws-sdk-pi/client.rb', line 1400 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to the Amazon RDS Performance Insights resource.
1444 1445 1446 1447 |
# File 'lib/aws-sdk-pi/client.rb', line 1444 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Deletes the metadata tags from the Amazon RDS Performance Insights resource.
1484 1485 1486 1487 |
# File 'lib/aws-sdk-pi/client.rb', line 1484 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1513 1514 1515 |
# File 'lib/aws-sdk-pi/client.rb', line 1513 def waiter_names [] end |